aboutsummaryrefslogtreecommitdiff
path: root/platform/ext/psoc64.cmake
diff options
context:
space:
mode:
authorKevin Peng <kevin.peng@arm.com>2020-05-21 15:51:36 +0800
committerKevin Peng <kevin.peng@arm.com>2020-06-24 10:40:22 +0800
commit2131fdb1b7e450a87b86926d22fa8d6b962617ac (patch)
treeab0faefb6e7d95e3dafc6bf4153726da9b9d7174 /platform/ext/psoc64.cmake
parent1fb8070ff51b88d4c79e438e6b0979d5239116b2 (diff)
downloadtrusted-firmware-m-2131fdb1b7e450a87b86926d22fa8d6b962617ac.tar.gz
Build: Replace CMSIS_5_DIR with deeper CMSIS_DIR
This patch replaces the CMake variable CMSIS_5_DIR with the deeper CMSIS_5_DIR/CMSIS. This is the preparation for the RTX references from CMSIS_5 repo to tf-m-tests repo. Because setting 'CMSIS_5_DIR' to 'tf-m-tests' could be confusing. With this change, the 'CMSIS_DIR' would be set to 'tf-m-tests/CMSIS' later. Change-Id: I3bf19d15592a24cb718b220d8efc49f42b40f56d Signed-off-by: Kevin Peng <kevin.peng@arm.com>
Diffstat (limited to 'platform/ext/psoc64.cmake')
-rw-r--r--platform/ext/psoc64.cmake18
1 files changed, 9 insertions, 9 deletions
diff --git a/platform/ext/psoc64.cmake b/platform/ext/psoc64.cmake
index bcf78245d0..f59142333e 100644
--- a/platform/ext/psoc64.cmake
+++ b/platform/ext/psoc64.cmake
@@ -47,25 +47,25 @@ set(PLATFORM_DIR ${CMAKE_CURRENT_LIST_DIR})
if(COMPILER STREQUAL "ARMCLANG")
set (S_SCATTER_FILE_NAME "${PLATFORM_DIR}/common/armclang/tfm_common_s.sct")
set (NS_SCATTER_FILE_NAME "${PLATFORM_DIR}/target/cypress/psoc64/Device/Source/armclang/psoc6_ns.sct")
- if (DEFINED CMSIS_5_DIR)
- # not all project defines CMSIS_5_DIR, only the ones that use it.
- set (RTX_LIB_PATH "${CMSIS_5_DIR}/CMSIS/RTOS2/RTX/Library/ARM/RTX_CM4F.lib")
+ if (DEFINED CMSIS_DIR)
+ # not all project defines CMSIS_DIR, only the ones that use it.
+ set (RTX_LIB_PATH "${CMSIS_DIR}/RTOS2/RTX/Library/ARM/RTX_CM4F.lib")
endif()
elseif(COMPILER STREQUAL "GNUARM")
set (S_SCATTER_FILE_NAME "${PLATFORM_DIR}/common/gcc/tfm_common_s.ld")
set (NS_SCATTER_FILE_NAME "${PLATFORM_DIR}/target/cypress/psoc64/Device/Source/gcc/psoc6_ns.ld")
- if (DEFINED CMSIS_5_DIR)
- # not all project defines CMSIS_5_DIR, only the ones that use it.
+ if (DEFINED CMSIS_DIR)
+ # not all project defines CMSIS_DIR, only the ones that use it.
# [libRTX_CM3.a should be used for CM4 without FPU]
- set (RTX_LIB_PATH "${CMSIS_5_DIR}/CMSIS/RTOS2/RTX/Library/GCC/libRTX_CM3.a")
+ set (RTX_LIB_PATH "${CMSIS_DIR}/RTOS2/RTX/Library/GCC/libRTX_CM3.a")
endif()
elseif(COMPILER STREQUAL "IARARM")
set (S_SCATTER_FILE_NAME "${PLATFORM_DIR}/common/iar/tfm_common_s.icf")
set (NS_SCATTER_FILE_NAME "${PLATFORM_DIR}/target/cypress/psoc64/Device/Source/iar/psoc6_ns.icf")
- if (DEFINED CMSIS_5_DIR)
- # not all project defines CMSIS_5_DIR, only the ones that use it.
+ if (DEFINED CMSIS_DIR)
+ # not all project defines CMSIS_DIR, only the ones that use it.
# [RTX_CM3.a should be used for CM4 without FPU]
- set (RTX_LIB_PATH "${CMSIS_5_DIR}/CMSIS/RTOS2/RTX/Library/IAR/RTX_CM3.a")
+ set (RTX_LIB_PATH "${CMSIS_DIR}/RTOS2/RTX/Library/IAR/RTX_CM3.a")
endif()
else()
message(FATAL_ERROR "No startup file is available for compiler '${CMAKE_C_COMPILER_ID}'.")